==> nextcloud-29.0.12.tgz: nextcloud/apps/user_status/l10n/da.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Senestestatus",
    "No recent status changes" : "Ingen ændringer i status",
    "In a meeting" : "I et møde",
    "Commuting" : "Undervejs",
    "Out sick" : "Sygemeldt",
    "Vacationing" : "Holder ferie",
    "Out of office" : "Ikke på kontoret",
    "Working remotely" : "Arbejder hjemmefra",
    "In a call" : "Taler i telefon",
    "User status" : "Brugerstatus",
    "Clear status after" : "Ryd status efter",
    "Emoji for your status message" : "Emoji til din statusbesked",
    "What is your status?" : "Hvad er din status",
    "Predefined statuses" : "Foruddefinerede status",
    "Previously set" : "Tidligere sat",
    "Reset status" : "Nulstil status",
    "Set status" : "Sæt status",
    "Online status" : "Online status",
    "Status message" : "Statusbesked",
    "Set absence period" : "Indstil fraværs periode",
    "Set absence period and replacement" : "Indstil fraværs periode og angiv afløser",
    "Your status was set automatically" : "Status sat automatisk",
    "Clear status message" : "Ryd statusnotifikation",
    "Set status message" : "Sæt statusbesked",
    "Reset status to \"{icon} {message}\"" : "Nulstil status til \"{icon}{message}\"",
    "Reset status to \"{message}\"" : "Nulstil status til \"{message}\"",
    "Reset status to \"{icon}\"" : "Nulstil status til \"{icon}\"",
    "There was an error saving the status" : "Der opstod en fejl ved lagring af status",
    "There was an error clearing the status" : "Der opstod en fejl ved rydning af status",
    "There was an error reverting the status" : "Der opstod en fejl ved indstillingen af status",
    "Don't clear" : "Ryd ikke",
    "Today" : "I dag",
    "This week" : "Denne uge",
    "Online" : "Online",
    "Away" : "Ikke tilstede",
    "Do not disturb" : "Forstyr ikke",
    "Invisible" : "Usynlig",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Der opstod en fejl ved lagring af den nye status",
    "30 minutes" : "30 minutter",
    "1 hour" : "1 time",
    "4 hours" : "4 timer",
    "Mute all notifications" : "Vis ikke notifikationer",
    "Appear offline" : "Er offline"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/user_status/l10n/da.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Seneste status",
    "No recent status changes" : "Ingen ændringer i status",
    "In a meeting" : "I møde",
    "Commuting" : "Under vejs",
    "Out sick" : "Sygemeldt",
    "Vacationing" : "Holder ferie",
    "Out of office" : "Ikke på kontoret",
    "Working remotely" : "Arbejder hjemmefra",
    "In a call" : "Taler i telefon",
    "User status" : "Bruger status",
    "Clear status after" : "Ryd status efter",
    "Emoji for your status message" : "Emoji til din statusbesked",
    "What is your status?" : "Hvad er din status",
    "Predefined statuses" : "Foruddefinerede status",
    "Previously set" : "Tidligere sat",
    "Reset status" : "Nulstil status",
    "Set status" : "Sæt status",
    "Online status" : "Online status",
    "Status message" : "Statusbesked",
    "Set absence period" : "Indstil fraværs periode",
    "Set absence period and replacement" : "Indstil fraværs periode og angiv afløser",
    "Your status was set automatically" : "Status sat automatisk",
    "Clear status message" : "Ryd status notifikation",
    "Set status message" : "Sæt statusbesked",
    "Reset status to \"{icon} {message}\"" : "Nulstil status til \"{icon}{message}\"",
    "Reset status to \"{message}\"" : "Nulstil status til \"{message}\"",
    "Reset status to \"{icon}\"" : "Nulstil status til \"{icon}\"",
    "There was an error saving the status" : "Der opstod en fejl ved lagring af status",
    "There was an error clearing the status" : "Der opstod en fejl ved rydning af status",
    "There was an error reverting the status" : "Der opstod en fejl ved indstillingen af status",
    "Don't clear" : "Ryd ikke",
    "Today" : "I dag",
    "This week" : "Denne uge",
    "Online" : "Online",
    "Away" : "Ikke tilstede",
    "Do not disturb" : "Forstyr ikke",
    "Invisible" : "Usynlig",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Der opstod en fejl ved lagring af den nye status",
    "30 minutes" : "30 minutter",
    "1 hour" : "1 time",
    "4 hours" : "4 timer",
    "Mute all notifications" : "Vis ikke notifikationer",
    "Appear offline" : "Er offline"
},
"nplurals=2; plural=(n != 1);");
